@@ -19,7 +19,7 @@ class GeneralUtil:
         """
         LOGGER = CustomLogger.getLogger()
         # this is a list of common kwargs that sometimes linger in kwargs to be used later.
-        IGNORE_KWARGS = ["validateLeague", "validateYear", "validateWeek", "validateMatchup"]
+        IGNORE_KWARGS = ["validate"]
         unused_kwargs = [kwarg for kwarg in kwargs.keys() if kwarg not in IGNORE_KWARGS]
         for kwarg in unused_kwargs:
             LOGGER.warning(f"Keyword argument '{kwarg}' unused.")
